import{d as c,eB as m,u as e,b as d,c as u,ev as y,f as a,w as o,bv as _,ar as p,ex as g,e as x,eD as b}from"./outputWidgets.73e48adb.js";import"./router.32167d1f.js";import"./index.9dbecee6.js";import{O as w}from"./organization.f581c0b9.js";import{a as k}from"./asyncComputed.02c9e941.js";import{A}from"./Title.42a97159.js";import{A as B}from"./index.27d555b2.js";import{A as h}from"./index.54a44884.js";import{A as C}from"./Text.6ed098e9.js";import{C as v}from"./Card.b66b1ceb.js";import"./Form.96a128f7.js";import"./hasIn.e1935081.js";import"./index.cf4c23b9.js";import"./record.dad9df30.js";import"./pubsub.5ce27a1f.js";import"./Base.dc6b2177.js";import"./Typography.343bcd00.js";import"./TabPane.888ceff6.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[r]="1ea3962f-f76e-4767-99c3-6c7ac2aef26a",t._sentryDebugIdIdentifier="sentry-dbid-1ea3962f-f76e-4767-99c3-6c7ac2aef26a")}catch{}})();const D={key:1},I={style:{display:"flex","justify-content":"flex-end","font-size":"24px"}},W=c({__name:"Billing",setup(t){const n=m().params.organizationId,{loading:f,result:l}=k(()=>w.get(n));return(z,N)=>e(f)?(d(),u(e(_),{key:0})):(d(),y("div",D,[a(e(B),{justify:"space-between",align:"center"},{default:o(()=>[a(e(A),{level:3},{default:o(()=>[p("Current plan")]),_:1}),g("",!0)]),_:1}),a(e(h),{style:{"margin-top":"0"}}),a(e(v),{style:{width:"300px"}},{default:o(()=>{var i,s;return[a(e(C),{type:"secondary"},{default:o(()=>[p("Plan")]),_:1}),x("div",I,b((s=(i=e(l))==null?void 0:i.billingMetadata)==null?void 0:s.plan),1)]}),_:1})]))}});export{W as default};
//# sourceMappingURL=Billing.58934aaa.js.map
