import{V as s,f as d,Q as p}from"./outputWidgets.73e48adb.js";import{B as i,b}from"./Base.dc6b2177.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="58b7e4cb-2d14-4121-ae5d-ac2485adb655",a._sentryDebugIdIdentifier="sentry-dbid-58b7e4cb-2d14-4121-ae5d-ac2485adb655")}catch{}})();const c=()=>p(b(),["component"]),r=(a,e)=>{let{slots:t,attrs:o}=e;const n=s(s(s({},a),{component:"div"}),o);return d(i,n,t)};r.displayName="ATypographyParagraph";r.inheritAttrs=!1;r.props=c();const g=r;export{g as A};
//# sourceMappingURL=Paragraph.2c7f637b.js.map
