import{cz as r}from"./outputWidgets.73e48adb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="605cf3e1-27be-4ca9-aad1-0feedbd63edd",e._sentryDebugIdIdentifier="sentry-dbid-605cf3e1-27be-4ca9-aad1-0feedbd63edd")}catch{}})();const t=(e,d)=>{r.error({message:e,description:d})};export{t as p};
//# sourceMappingURL=popupNotifcation.f1426b26.js.map
