import{ac as i,V as t,Q as d,f as p}from"./outputWidgets.73e48adb.js";import{B as l,b as c}from"./Base.dc6b2177.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="70b513de-34fb-4d4f-aeae-ce83755dfa59",e._sentryDebugIdIdentifier="sentry-dbid-70b513de-34fb-4d4f-aeae-ce83755dfa59")}catch{}})();const b=()=>t(t({},d(c(),["component"])),{ellipsis:{type:[Boolean,Object],default:void 0}}),o=(e,s)=>{let{slots:a,attrs:r}=s;const{ellipsis:n}=e;i();const f=t(t(t({},e),{ellipsis:n&&typeof n=="object"?d(n,["expandable","rows"]):n,component:"span"}),r);return p(l,f,a)};o.displayName="ATypographyText";o.inheritAttrs=!1;o.props=b();const g=o;export{g as A};
//# sourceMappingURL=Text.6ed098e9.js.map
