import{eN as t,eO as r}from"./outputWidgets.73e48adb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="fdd2ec74-9115-4131-8c89-8089367ba9ef",e._sentryDebugIdIdentifier="sentry-dbid-fdd2ec74-9115-4131-8c89-8089367ba9ef")}catch{}})();function o(e,n){return t(1,arguments),r(e,Date.now(),n)}export{o as f};
//# sourceMappingURL=index.1fd851ee.js.map
