import{B as s}from"./Base.dc6b2177.js";import{A as a}from"./Link.5116a740.js";import{A as o}from"./Paragraph.2c7f637b.js";import{A as r}from"./Text.6ed098e9.js";import{A as i}from"./Title.42a97159.js";import{T as e}from"./Typography.343bcd00.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="876413b3-5eef-4265-a487-c44a7a9e41c5",n._sentryDebugIdIdentifier="sentry-dbid-876413b3-5eef-4265-a487-c44a7a9e41c5")}catch{}})();e.Text=r;e.Title=i;e.Paragraph=o;e.Link=a;e.Base=s;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,r),n.component(e.Title.displayName,i),n.component(e.Paragraph.displayName,o),n.component(e.Link.displayName,a),n};
//# sourceMappingURL=index.0ce79f9a.js.map
