import"./outputWidgets.73e48adb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="16a97916-05a5-4ed5-9889-a13609733b44",e._sentryDebugIdIdentifier="sentry-dbid-16a97916-05a5-4ed5-9889-a13609733b44")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.ee9a902a.js.map
