import{v as t,b as s,ev as o}from"./outputWidgets.73e48adb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="830e7a67-5f06-4ea0-bbeb-fd93fbf08145",e._sentryDebugIdIdentifier="sentry-dbid-830e7a67-5f06-4ea0-bbeb-fd93fbf08145")}catch{}})();const r={},a={class:"organization-settings"};function f(e,n){return s(),o("div",a,"Organization settings")}const c=t(r,[["render",f]]);export{c as default};
//# sourceMappingURL=OrganizationSettings.ca96a39e.js.map
