import{_ as s}from"./Navbar.vue_vue_type_script_setup_true_lang.120e0524.js";import{K as f,P as l,L as d}from"./repository.c59c401d.js";import{d as u,b as c,ev as b,f as p,u as r}from"./outputWidgets.73e48adb.js";import{u as g}from"./index.eca7b9b0.js";import{a as y}from"./asyncComputed.02c9e941.js";import{g as _}from"./api.c9bc091e.js";import"./Text.6ed098e9.js";import"./Base.dc6b2177.js";import"./Typography.343bcd00.js";import"./index.0ce79f9a.js";import"./Link.5116a740.js";import"./Paragraph.2c7f637b.js";import"./Title.42a97159.js";import"./index.84f0c193.js";import"./ArrowRightOutlined.08fa31dd.js";import"./api.b9f507c0.js";import"./index.cf4c23b9.js";import"./icons.37a32d23.js";import"./index.27d555b2.js";import"./ant-design.643041cf.js";import"./index.7995cda6.js";import"./Modal.cc696ff2.js";import"./index.198d7afa.js";import"./index.1fd851ee.js";import"./index.74d27eeb.js";import"./CollapsePanel.e0d4624d.js";import"./Form.96a128f7.js";import"./hasIn.e1935081.js";import"./Timeline.a44f66f6.js";import"./index.54a44884.js";import"./index.eb7cf389.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.d2747ae2.js";import"./workspaces.ca95d07a.js";import"./runnerData.737f4318.js";import"./url.ee9a902a.js";import"./record.dad9df30.js";import"./pubsub.5ce27a1f.js";import"./scripts.043ac47e.js";import"./envVars.77ca5967.js";import"./ExpandOutlined.ab48bbdb.js";import"./Card.b66b1ceb.js";import"./TabPane.888ceff6.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[t]="683e40b0-081c-4382-a966-835545ff4e46",o._sentryDebugIdIdentifier="sentry-dbid-683e40b0-081c-4382-a966-835545ff4e46")}catch{}})();const fo=u({__name:"Kanban",setup(o){const t=new l(g),a=new d("kanban"),{result:e}=y(_);return(k,w)=>{var i,n,m;return c(),b("div",null,[p(s,{"brand-name":((i=r(e))==null?void 0:i.brandName)||((n=r(e))==null?void 0:n.name),"logo-url":(m=r(e))==null?void 0:m.logoUrl},null,8,["brand-name","logo-url"]),p(f,{"kanban-repository":r(t),storage:r(a)},null,8,["kanban-repository","storage"])])}}});export{fo as default};
//# sourceMappingURL=Kanban.f5175a70.js.map
