import{C as r,E as t,K as i,a as f,M as l,c as y,P as b,R as c,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.6c9a9b39.js";import"./outputWidgets.73e48adb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="b98dea86-dfed-426d-94e4-43574091553f",e._sentryDebugIdIdentifier="sentry-dbid-b98dea86-dfed-426d-94e4-43574091553f")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,f as KeyMod,l as MarkerSeverity,y as MarkerTag,b as Position,c as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.357a2fb5.js.map
