import{S as p}from"./Sidebar.2c996fc0.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.7f3dbb16.js";import{L as d,M as l,N as u}from"./icons.37a32d23.js";import{d as b,eB as f,H as g,a as _,b as y,c as v,w as a,f as r}from"./outputWidgets.73e48adb.js";import{a as w}from"./asyncComputed.02c9e941.js";import"./router.32167d1f.js";import"./index.9dbecee6.js";import{O as z}from"./organization.f581c0b9.js";import{B as h}from"./BaseLayout.d2951c5f.js";import"./index.198d7afa.js";import"./logo.084e5d7c.js";import"./Text.6ed098e9.js";import"./Base.dc6b2177.js";import"./Typography.343bcd00.js";import"./index.84f0c193.js";import"./ArrowRightOutlined.08fa31dd.js";import"./Form.96a128f7.js";import"./hasIn.e1935081.js";import"./index.cf4c23b9.js";import"./record.dad9df30.js";import"./pubsub.5ce27a1f.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="04312dd7-b45c-4929-a726-6390eea3397e",o._sentryDebugIdIdentifier="sentry-dbid-04312dd7-b45c-4929-a726-6390eea3397e")}catch{}})();const K=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:t}=w(()=>z.get(n)),i=g(()=>t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.name,path:`/organizations/${t.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing"}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:a(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:a(()=>[r(p,{class:"sidebar",sections:s})]),content:a(()=>[r(m)]),_:1})}}});export{K as default};
//# sourceMappingURL=Organization.e2058d0f.js.map
