import{r as a,w as r}from"./runnerData.737f4318.js";import"./outputWidgets.73e48adb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="6dabcbe3-ee7a-41ec-99ce-e0cb2826f757",e._sentryDebugIdIdentifier="sentry-dbid-6dabcbe3-ee7a-41ec-99ce-e0cb2826f757")}catch{}})();async function c(e){const t=await fetch(`/_pages/${e}`);if(t.status==404)return null;if(!t.ok)throw new Error(await t.text());const{form:n}=await t.json();return n?a(n):null}async function f(){const e=await fetch("/_workspace");if(e.status!=200)return r({});const t=await e.json();return r(t)}export{c as f,f as g};
//# sourceMappingURL=api.c9bc091e.js.map
