import{g as d}from"./api.c9bc091e.js";import{P as m}from"./Passwordless.e34cf0d9.js";import{a as f}from"./asyncComputed.02c9e941.js";import{W as p}from"./WidgetsFrame.a58f3fea.js";import{d as u,eA as l,eB as _,b as c,ev as y,e as g,u as s,c as b,w as h,ex as w,f as v,v as k}from"./outputWidgets.73e48adb.js";import"./runnerData.737f4318.js";import"./url.ee9a902a.js";import"./index.eca7b9b0.js";import"./pubsub.5ce27a1f.js";import"./icons.37a32d23.js";import"./CircularLoading.1aebf8ec.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="c3afc08e-4347-4854-8c72-f72c2aebf936",e._sentryDebugIdIdentifier="sentry-dbid-c3afc08e-4347-4854-8c72-f72c2aebf936")}catch{}})();const x={class:"login"},I=u({__name:"Login",setup(e){const t=l(),a=_(),{result:o}=f(d),i=()=>{const{redirect:r,...n}=a.query;if(r){t.push({path:r,query:n,params:a.params});return}t.push({name:"playerKanban",query:n})};return(r,n)=>(c(),y("div",null,[g("div",x,[s(o)?(c(),b(p,{key:0,"main-color":s(o).mainColor,theme:s(o).theme,"font-family":s(o).fontFamily,style:{width:"100vw"}},{default:h(()=>[v(m,{onDone:i})]),_:1},8,["main-color","theme","font-family"])):w("",!0)])]))}});const R=k(I,[["__scopeId","data-v-33714d9d"]]);export{R as default};
//# sourceMappingURL=Login.da0ebdf2.js.map
