import{K as n,E as p,L as a}from"./repository.c59c401d.js";import{d as s,b as m,c,u as e}from"./outputWidgets.73e48adb.js";import{l as d}from"./index.eca7b9b0.js";import"./asyncComputed.02c9e941.js";import"./api.b9f507c0.js";import"./index.cf4c23b9.js";import"./icons.37a32d23.js";import"./index.27d555b2.js";import"./ant-design.643041cf.js";import"./index.7995cda6.js";import"./Modal.cc696ff2.js";import"./Text.6ed098e9.js";import"./Base.dc6b2177.js";import"./Typography.343bcd00.js";import"./index.198d7afa.js";import"./index.1fd851ee.js";import"./Paragraph.2c7f637b.js";import"./index.0ce79f9a.js";import"./Link.5116a740.js";import"./Title.42a97159.js";import"./index.74d27eeb.js";import"./CollapsePanel.e0d4624d.js";import"./Form.96a128f7.js";import"./hasIn.e1935081.js";import"./Timeline.a44f66f6.js";import"./index.54a44884.js";import"./index.eb7cf389.js";import"./isNumeric.75337b1e.js";import"./contracts.generated.d2747ae2.js";import"./workspaces.ca95d07a.js";import"./runnerData.737f4318.js";import"./url.ee9a902a.js";import"./record.dad9df30.js";import"./pubsub.5ce27a1f.js";import"./scripts.043ac47e.js";import"./envVars.77ca5967.js";import"./ExpandOutlined.ab48bbdb.js";import"./Card.b66b1ceb.js";import"./TabPane.888ceff6.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[o]="5b1213ae-5ec4-4fab-8574-e5ec07dc5b4b",t._sentryDebugIdIdentifier="sentry-dbid-5b1213ae-5ec4-4fab-8574-e5ec07dc5b4b")}catch{}})();class b{constructor(o=d){this.fetch=o}async fork(o){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:o}),headers:{"Content-Type":"application/json"}})).json()}}const oo=s({__name:"WorkflowKanban",setup(t){const o=new p,r=new b,i=new a("kanban");return(f,u)=>(m(),c(n,{"kanban-repository":e(o),storage:e(i),"stage-run-repository":e(r)},null,8,["kanban-repository","storage","stage-run-repository"]))}});export{oo as default};
//# sourceMappingURL=WorkflowKanban.cd821019.js.map
